@@ -1,7 +1,9 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2019-09-10'; # DATE
-our $VERSION = '0.472'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-12-19'; # DATE
+our $DIST = 'Complete-Getopt-Long'; # DIST
+our $VERSION = '0.473'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,8 +67,10 @@ sub _default_completion {
     # to the routine)
     if ($word =~ m!\A(~[^/]*)/!) {
         #$log->tracef("[comp][compgl] completing file, path=<%s>", $word);
-        $fres = {words=>Complete::File::complete_file(word=>$word),
-                 path_sep=>'/'};
+        $fres = Complete::Util::hashify_answer(
+            Complete::File::complete_file(word=>$word),
+            {path_sep=>'/'}
+        );
         goto RETURN_RES;
     }
 
@@ -88,8 +92,10 @@ sub _default_completion {
         # if empty, fallback to searching file
     }
     #$log->tracef("[comp][compgl] completing with file, file=<%s>", $word);
-    $fres = {words=>Complete::File::complete_file(word=>$word),
-             path_sep=>'/'};
+    $fres = Complete::Util::hashify_answer(
+        Complete::File::complete_file(word=>$word),
+        {path_sep=>'/'}
+    );
   RETURN_RES:
     #$log->tracef("[comp][compgl] leaving default completion routine, result=%s", $fres);
     $fres;
@@ -737,7 +743,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.472 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2019-09-10.
+This document describes version 0.473 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2019-12-19.
 
 =head1 SYNOPSIS
 
